@@ -26,7 +26,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 */
 
@@ -917,7 +917,7 @@ makefs(const char *devpath, const char *fstype)
 	autopartkit_log(1, "  Unknown fs '%s' for dev '%s'\n", fstype,devpath);
 	return -1;
       }
-    retval = asprintf(&cmd, "%s %s >> /var/log/messages 2>&1", mkfs, devpath);
+    retval = asprintf(&cmd, "log-output -t autopartkit %s %s", mkfs, devpath);
     if (-1 != retval)
       {
 	autopartkit_log(1, "Running command: %s\n", cmd);
